==> gnocl-0.5.15.tar.bz2: gnocl-0.5.15/src/eventBox.c <==
/*
 * $Id: eventBox.c,v 1.6 2004/02/10 20:57:35 baum Exp $
 *
 * This file implements the eventBox widget
 *
 * Copyright (c) 2002 - 2004 Peter G. Baum  http://www.dr-baum.net
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
   History:
   2003-02: added drag and drop options
   2003-01: switched from GnoclWidgetOptions to GnoclOption
   2002-01: Begin of developement
 */
/*
   TODO? handle invisible for user? Or only for gnocl::box?
*/

#include "gnocl.h"
#include <string.h>
#include <assert.h>

static GnoclOption boxOptions[] =
{
   { "-child", GNOCL_STRING, NULL },
   { "-name", GNOCL_STRING, "name" },
   { "-visible", GNOCL_BOOL, "visible" }, 
   { "-tooltip", GNOCL_OBJ, "", gnoclOptTooltip },
   { "-sensitive", GNOCL_BOOL, "sensitive" }, 
   { "-onShowHelp", GNOCL_OBJ, "", gnoclOptOnShowHelp }, 
   { "-onPopupMenu", GNOCL_OBJ, "popup-menu", gnoclOptCommand }, 
   { "-onDestroy", GNOCL_OBJ, "destroy", gnoclOptCommand }, 
   { "-background", GNOCL_OBJ, "normal", gnoclOptGdkColorBg },
   { "-onButtonPress", GNOCL_OBJ, "P", gnoclOptOnButton },
   { "-onButtonRelease", GNOCL_OBJ, "R", gnoclOptOnButton },
   { "-onMotion", GNOCL_OBJ, "", gnoclOptOnMotion },
   { "-dropTargets", GNOCL_LIST, "t", gnoclOptDnDTargets },
   { "-dragTargets", GNOCL_LIST, "s", gnoclOptDnDTargets },
   { "-onDropData", GNOCL_OBJ, "", gnoclOptOnDropData },
   { "-onDragData", GNOCL_OBJ, "", gnoclOptOnDragData },
   { "-hasFocus", GNOCL_BOOL, "has-focus" },
   { "-widthGroup", GNOCL_OBJ, "w", gnoclOptSizeGroup }, 
   { "-heightGroup", GNOCL_OBJ, "h", gnoclOptSizeGroup }, 
   { "-sizeGroup", GNOCL_OBJ, "s", gnoclOptSizeGroup }, 
   { NULL }
};

static const int childIdx   = 0;

static int configure( Tcl_Interp *interp, GtkEventBox *box,
      GnoclOption *options )
{
   /*
      FIXME: delete old child
      if( gtk_container_children( GTK_CONTAINER( parent ) ) != NULL )
   */
   if( options[childIdx].status == GNOCL_STATUS_CHANGED )
   {
      GtkWidget *childWidget = gnoclChildNotPacked( 
            options[childIdx].val.str, interp );
      if( childWidget == NULL )
         return TCL_ERROR;

      gtk_container_add( GTK_CONTAINER( box ), childWidget );
   }

   return TCL_OK;
}

static int eventBoxFunc( ClientData data, Tcl_Interp *interp,
      int objc, Tcl_Obj * const objv[] )
{
   static const char *cmds[] = { "delete", "configure", NULL };
   enum cmdIdx { DeleteIdx, ConfigureIdx };
   GtkEventBox *box = GTK_EVENT_BOX( data );
   int idx;

   if( objc < 2 )
   {
      Tcl_WrongNumArgs( interp, 1, objv, "command" );
      return TCL_ERROR;
   }

   if( Tcl_GetIndexFromObj( interp, objv[1], cmds, "command", 
         TCL_EXACT, &idx ) != TCL_OK )
      return TCL_ERROR;

   switch( idx )
   {
      case DeleteIdx:
            return gnoclDelete( interp, GTK_WIDGET( box ), objc, objv );

      case ConfigureIdx:
            {
               int ret = TCL_ERROR;
               if( gnoclParseAndSetOptions( interp, objc - 1, objv + 1, 
                     boxOptions, G_OBJECT( box ) ) == TCL_OK )
               {
                  ret = configure( interp, box, boxOptions );
               }
               gnoclClearOptions( boxOptions );
               return ret;
            }
            break;
   }

   return TCL_OK;
}

int gnoclEventBoxCmd( ClientData data, Tcl_Interp *interp,
      int objc, Tcl_Obj * const objv[] )
{
   int         ret;
   GtkEventBox *box;
   
   if( gnoclParseOptions( interp, objc, objv, boxOptions ) 
         != TCL_OK )
   {
      gnoclClearOptions( boxOptions );
      return TCL_ERROR;
   }

   box = GTK_EVENT_BOX( gtk_event_box_new( ) );
   gtk_widget_show( GTK_WIDGET( box ) );

   ret = gnoclSetOptions( interp, boxOptions, G_OBJECT( box ), -1 );
   if( ret == TCL_OK )
      ret = configure( interp, box, boxOptions );
   gnoclClearOptions( boxOptions );

   if( ret != TCL_OK )
   {
      gtk_widget_destroy( GTK_WIDGET( box ) );
      return TCL_ERROR;
   }

   return gnoclRegisterWidget( interp, GTK_WIDGET( box ), eventBoxFunc );
}

==> gnocl-0.5.18.tar.bz2: gnocl-0.5.18/src/eventBox.c <==
/*
 * $Id: eventBox.c,v 1.7 2004/04/05 18:16:39 baum Exp $
 *
 * This file implements the eventBox widget
 *
 * Copyright (c) 2002 - 2004 Peter G. Baum  http://www.dr-baum.net
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
   History:
   2003-02: added drag and drop options
   2003-01: switched from GnoclWidgetOptions to GnoclOption
   2002-01: Begin of developement
 */
/*
   TODO? handle invisible for user? Or only for gnocl::box?
*/

#include "gnocl.h"
#include <string.h>
#include <assert.h>

static GnoclOption boxOptions[] =
{
   { "-child", GNOCL_OBJ, "", gnoclOptChild },
   { "-name", GNOCL_STRING, "name" },
   { "-visible", GNOCL_BOOL, "visible" }, 
   { "-tooltip", GNOCL_OBJ, "", gnoclOptTooltip },
   { "-sensitive", GNOCL_BOOL, "sensitive" }, 
   { "-onShowHelp", GNOCL_OBJ, "", gnoclOptOnShowHelp }, 
   { "-onPopupMenu", GNOCL_OBJ, "popup-menu", gnoclOptCommand }, 
   { "-onDestroy", GNOCL_OBJ, "destroy", gnoclOptCommand }, 
   { "-background", GNOCL_OBJ, "normal", gnoclOptGdkColorBg },
   { "-onButtonPress", GNOCL_OBJ, "P", gnoclOptOnButton },
   { "-onButtonRelease", GNOCL_OBJ, "R", gnoclOptOnButton },
   { "-onMotion", GNOCL_OBJ, "", gnoclOptOnMotion },
   { "-dropTargets", GNOCL_LIST, "t", gnoclOptDnDTargets },
   { "-dragTargets", GNOCL_LIST, "s", gnoclOptDnDTargets },
   { "-onDropData", GNOCL_OBJ, "", gnoclOptOnDropData },
   { "-onDragData", GNOCL_OBJ, "", gnoclOptOnDragData },
   { "-hasFocus", GNOCL_BOOL, "has-focus" },
   { "-widthGroup", GNOCL_OBJ, "w", gnoclOptSizeGroup }, 
   { "-heightGroup", GNOCL_OBJ, "h", gnoclOptSizeGroup }, 
   { "-sizeGroup", GNOCL_OBJ, "s", gnoclOptSizeGroup }, 
   { NULL }
};

static int eventBoxFunc( ClientData data, Tcl_Interp *interp,
      int objc, Tcl_Obj * const objv[] )
{
   static const char *cmds[] = { "delete", "configure", NULL };
   enum cmdIdx { DeleteIdx, ConfigureIdx };
   GtkEventBox *box = GTK_EVENT_BOX( data );
   int idx;

   if( objc < 2 )
   {
      Tcl_WrongNumArgs( interp, 1, objv, "command" );
      return TCL_ERROR;
   }

   if( Tcl_GetIndexFromObj( interp, objv[1], cmds, "command", 
         TCL_EXACT, &idx ) != TCL_OK )
      return TCL_ERROR;

   switch( idx )
   {
      case DeleteIdx:
            return gnoclDelete( interp, GTK_WIDGET( box ), objc, objv );

      case ConfigureIdx:
            {
               int ret = gnoclParseAndSetOptions( interp, objc - 1, objv + 1, 
                     boxOptions, G_OBJECT( box ) );
               gnoclClearOptions( boxOptions );
               return ret;
            }
            break;
   }

   return TCL_OK;
}

int gnoclEventBoxCmd( ClientData data, Tcl_Interp *interp,
      int objc, Tcl_Obj * const objv[] )
{
   int         ret;
   GtkEventBox *box;
   
   if( gnoclParseOptions( interp, objc, objv, boxOptions ) 
         != TCL_OK )
   {
      gnoclClearOptions( boxOptions );
      return TCL_ERROR;
   }

   box = GTK_EVENT_BOX( gtk_event_box_new( ) );
   gtk_widget_show( GTK_WIDGET( box ) );

   ret = gnoclSetOptions( interp, boxOptions, G_OBJECT( box ), -1 );
   gnoclClearOptions( boxOptions );

   if( ret != TCL_OK )
   {
      gtk_widget_destroy( GTK_WIDGET( box ) );
      return TCL_ERROR;
   }

   return gnoclRegisterWidget( interp, GTK_WIDGET( box ), eventBoxFunc );
}
